==> openjdk11-11.0.29_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_dsb.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_dsb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ALL", "ALL" },
            { "AUD", "AUD" },
            { "BGN", "BGN" },
            { "JPY", "\u00a5" },
            { "KPW", "KPW" },
            { "PLN", "z\u0142" },
            { "THB", "\u0e3f" },
            { "USD", "$" },
            { "adp", "andorraska peseta" },
            { "aed", "ZAE dirham" },
            { "afn", "afghaniski afgani" },
            { "all", "alba\u0144ski lek" },
            { "amd", "arme\u0144ski dram" },
            { "ang", "ni\u017eozemsko-antilski gulden" },
            { "aoa", "angolska kwanza" },
            { "aok", "angolska kwanza (1977\u20131990)" },
            { "aon", "angolska nowa kwanza (1990\u20132000)" },
            { "aor", "angolska kwanza reajustado (1995\u20131999)" },
            { "ara", "argentinski austral" },
            { "arp", "argentinski peso (1983\u20131985)" },
            { "ars", "argentinski peso" },
            { "ats", "rakuski \u0161iling" },
            { "aud", "awstralski dolar" },
            { "awg", "aruba-florin" },
            { "azm", "azerbajd\u017eaniski manat (1993\u20132006)" },
            { "azn", "azerbajd\u017eaniski manat" },
            { "bad", "bosniski dinar" },
            { "bam", "bosniska konwertibelna marka" },
            { "bbd", "barbadoski dolar" },
            { "bdt", "banglade\u0161ska taka" },
            { "bec", "belgiski frank (konwertibelny)" },
            { "bef", "belgiski frank" },
            { "bel", "belgiski financny frank" },
            { "bgl", "bulgarski lew (1962\u20131999)" },
            { "bgn", "bulgarski lew" },
            { "bhd", "bahrainski dinar" },
            { "bif", "burundiski frank" },
            { "bmd", "bermudaski dolar" },
            { "bnd", "bruneiski dolar" },
            { "bob", "boliwiski boliviano" },
            { "bop", "boliwiski peso" },
            { "bov", "boliwiski mvdol" },
            { "brb", "brazilski nowy cruzeiro (1967\u20131986)" },
            { "brc", "brazilski cruzado (1986\u20131989)" },
            { "bre", "brazilski cruzeiro (1990\u20131993)" },
            { "brl", "brazilski real" },
            { "brn", "brazilski nowy cruzado (1989\u20131990)" },
            { "brr", "brazilski cruzeiro (1993\u20131994)" },
            { "bsd", "bahamaski dolar" },
            { "btn", "bhuta\u0144ski ngultrum" },
            { "buk", "burmaski kyat" },
            { "bwp", "botswaniska pula" },
            { "byb", "b\u011b\u0142oruski rubl (1994\u20131999)" },
            { "byn", "b\u011b\u0142oruski rubl" },
            { "byr", "b\u011b\u0142oruski rubl (2000\u20132016)" },
            { "bzd", "belizeski dolar" },
            { "cad", "kanadiski dolar" },
            { "cdf", "kongoski frank" },
            { "chf", "\u0161wicarski frank" },
            { "clp", "chilski peso" },
            { "cny", "chinski yuan" },
            { "cop", "kolumbiski peso" },
            { "crc", "kosta-rika\u0144ski col\u00f3n" },
            { "cuc", "kuba\u0144ski konwertibelny peso" },
            { "cup", "kuba\u0144ski peso" },
            { "cve", "kapverdski escudo" },
            { "czk", "\u010deska krona" },
            { "djf", "d\u017aibutiski frank" },
            { "dkk", "da\u0144ska krona" },
            { "dop", "dominika\u0144ski peso" },
            { "dzd", "algeriski dinar" },
            { "egp", "egyptojski punt" },
            { "ern", "eritrejska nakfa" },
            { "etb", "etiopiski birr" },
            { "eur", "euro" },
            { "fjd", "fid\u017aiski dolar" },
            { "fkp", "falklandski punt" },
            { "gbp", "britiski punt" },
            { "gel", "georgiski lari" },
            { "ghs", "ghanaski cedi" },
            { "gip", "gibraltiski punt" },
            { "gmd", "gambiski dalasi" },
            { "gnf", "guineski frank" },
            { "gtq", "guatemalski quetzal" },
            { "gwp", "Guinea-Bissau peso" },
            { "gyd", "guya\u0144ski dolar" },
            { "hkd", "hongkongski dolar" },
            { "hnl", "honduraska lempira" },
            { "hrk", "chorwatska kuna" },
            { "htg", "haitiska gourda" },
            { "huf", "mad\u017aarski forint" },
            { "idr", "indoneska rupija" },
            { "ils", "israelski nowy \u0161ekel" },
            { "inr", "indiska rupija" },
            { "iqd", "irakski dinar" },
            { "irr", "ira\u0144ski rial" },
            { "isk", "islandska krona" },
            { "jmd", "jamaiski dolar" },
            { "jod", "jordaniski dinar" },
            { "jpy", "japa\u0144ski yen" },
            { "kes", "keniaski \u0161iling" },
            { "kgs", "kirgiski som" },
            { "khr", "kambod\u017easki riel" },
            { "kmf", "komorski frank" },
            { "kpw", "p\u00f3dpo\u0142nocnokorejski won" },
            { "krw", "p\u00f3dpo\u0142dnjowokorejski won" },
            { "kwd", "kuwaitski dinar" },
            { "kyd", "kajmaniski dolar" },
            { "kzt", "kazachski tenge" },
            { "lak", "laoski kip" },
            { "lbp", "libano\u0144ski punt" },
            { "lkr", "sri-lankaska rupija" },
            { "lrd", "liberiski dolar" },
            { "ltl", "litawski litas" },
            { "lvl", "letiski lat" },
            { "lyd", "libyski dinar" },
            { "mad", "marokkoski dirham" },
            { "mdl", "moldawiski leu" },
            { "mga", "madagaskarski ariary" },
            { "mkd", "makedo\u0144ski denar" },
            { "mmk", "myanmarski kyat" },
            { "mnt", "mongolski tugrik" },
            { "mop", "macaoska pataca" },
            { "mro", "maureta\u0144ski ouguiya (1973\u20132017)" },
            { "mru", "maureta\u0144ski ouguiya" },
            { "mur", "mauriciska rupija" },
            { "mvr", "malediwiska rupija" },
            { "mwk", "malawiski kwacha" },
            { "mxn", "mexiski peso" },
            { "myr", "malajziski ringgit" },
            { "mze", "Mozabicke escudo" },
            { "mzm", "mosambikski metical (1980\u20132006)" },
            { "mzn", "mosambikski metical" },
            { "nad", "namibiski dolar" },
            { "ngn", "nigeriska naira" },
            { "nio", "nikaraguaska cordoba" },
            { "nok", "norwegska krona" },
            { "npr", "nepalska rupija" },
            { "nzd", "nowoseelandski dolar" },
            { "omr", "oma\u0144ski rial" },
            { "pab", "panamaski balboa" },
            { "pen", "peruski sol" },
            { "pgk", "papua-neuguinejska kina" },
            { "php", "filipinski peso" },
            { "pkr", "pakista\u0144ska rupija" },
            { "pln", "p\u00f3lski z\u0142oty" },
            { "pyg", "paraguayski guarani" },
            { "qar", "katarski rial" },
            { "ron", "rumu\u0144ski leu" },
            { "rsd", "serbiski dinar" },
            { "rub", "ruski rubl" },
            { "rwf", "ruandiski frank" },
            { "sar", "saudi-arabiski rial" },
            { "sbd", "salomo\u0144ski dolar" },
            { "scr", "seychelska rupija" },
            { "sdg", "suda\u0144ski punt" },
            { "sek", "\u0161wedska krona" },
            { "sgd", "singapurski dolar" },
            { "shp", "St. Helena punt" },
            { "sll", "sierra-leoneski leone" },
            { "sos", "somaliski \u0161iling" },
            { "srd", "surinamski dolar" },
            { "ssp", "p\u00f3dpo\u0142dnjowosuda\u0144ski punt" },
            { "std", "s\u00e3o-tomeska dobra (1977\u20132017)" },
            { "stn", "s\u00e3o-tomeska dobra" },
            { "svc", "el-salvadorski col\u00f3n" },
            { "syp", "syriski punt" },
            { "szl", "swasiski lilangeni" },
            { "thb", "thaiski baht" },
            { "tjs", "tad\u017aikiski somoni" },
            { "tmt", "turkmeniski manat" },
            { "tnd", "tuneziski dinar" },
            { "top", "tongaski pa\u02bbanga" },
            { "try", "turkojska lira" },
            { "ttd", "trinidad-tobagoski dolar" },
            { "twd", "nowy taiwa\u0144ski dolar" },
            { "tzs", "tansaniski \u0161iling" },
            { "uah", "ukrainska griwna" },
            { "ugx", "ugandaski \u0161iling" },
            { "usd", "ameriski dolar" },
            { "uyu", "uruguayski peso" },
            { "uzs", "usbekiski sum" },
            { "vef", "venezuelski bol\u00edvar" },
            { "vnd", "vietnamski dong" },
            { "vuv", "vanuatski vatu" },
            { "wst", "samoaska tala" },
            { "xaf", "CFA-frank (BEAC)" },
            { "xcd", "p\u00f3dzajt\u0161nokaribiski dolar" },
            { "xof", "CFA-frank (BCEAO)" },
            { "xpf", "CFP-frank" },
            { "xxx", "njeznate pjenjeze" },
            { "yer", "jeme\u0144ski rial" },
            { "zar", "p\u00f3dpo\u0142dnjowoafriski rand" },
            { "zmw", "sambiska kwacha" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_dsb.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_dsb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ALL", "ALL" },
            { "AUD", "AUD" },
            { "BGN", "BGN" },
            { "JPY", "\u00a5" },
            { "KPW", "KPW" },
            { "PLN", "z\u0142" },
            { "THB", "\u0e3f" },
            { "USD", "$" },
            { "adp", "andorraska peseta" },
            { "aed", "ZAE dirham" },
            { "afn", "afghaniski afgani" },
            { "all", "alba\u0144ski lek" },
            { "amd", "arme\u0144ski dram" },
            { "ang", "ni\u017eozemsko-antilski gulden" },
            { "aoa", "angolska kwanza" },
            { "aok", "angolska kwanza (1977\u20131990)" },
            { "aon", "angolska nowa kwanza (1990\u20132000)" },
            { "aor", "angolska kwanza reajustado (1995\u20131999)" },
            { "ara", "argentinski austral" },
            { "arp", "argentinski peso (1983\u20131985)" },
            { "ars", "argentinski peso" },
            { "ats", "rakuski \u0161iling" },
            { "aud", "awstralski dolar" },
            { "awg", "aruba-florin" },
            { "azm", "azerbajd\u017eaniski manat (1993\u20132006)" },
            { "azn", "azerbajd\u017eaniski manat" },
            { "bad", "bosniski dinar" },
            { "bam", "bosniska konwertibelna marka" },
            { "bbd", "barbadoski dolar" },
            { "bdt", "banglade\u0161ska taka" },
            { "bec", "belgiski frank (konwertibelny)" },
            { "bef", "belgiski frank" },
            { "bel", "belgiski financny frank" },
            { "bgl", "bulgarski lew (1962\u20131999)" },
            { "bgn", "bulgarski lew" },
            { "bhd", "bahrainski dinar" },
            { "bif", "burundiski frank" },
            { "bmd", "bermudaski dolar" },
            { "bnd", "bruneiski dolar" },
            { "bob", "boliwiski boliviano" },
            { "bop", "boliwiski peso" },
            { "bov", "boliwiski mvdol" },
            { "brb", "brazilski nowy cruzeiro (1967\u20131986)" },
            { "brc", "brazilski cruzado (1986\u20131989)" },
            { "bre", "brazilski cruzeiro (1990\u20131993)" },
            { "brl", "brazilski real" },
            { "brn", "brazilski nowy cruzado (1989\u20131990)" },
            { "brr", "brazilski cruzeiro (1993\u20131994)" },
            { "bsd", "bahamaski dolar" },
            { "btn", "bhuta\u0144ski ngultrum" },
            { "buk", "burmaski kyat" },
            { "bwp", "botswaniska pula" },
            { "byb", "b\u011b\u0142oruski rubl (1994\u20131999)" },
            { "byn", "b\u011b\u0142oruski rubl" },
            { "byr", "b\u011b\u0142oruski rubl (2000\u20132016)" },
            { "bzd", "belizeski dolar" },
            { "cad", "kanadiski dolar" },
            { "cdf", "kongoski frank" },
            { "chf", "\u0161wicarski frank" },
            { "clp", "chilski peso" },
            { "cny", "chinski yuan" },
            { "cop", "kolumbiski peso" },
            { "crc", "kosta-rika\u0144ski col\u00f3n" },
            { "cuc", "kuba\u0144ski konwertibelny peso" },
            { "cup", "kuba\u0144ski peso" },
            { "cve", "kapverdski escudo" },
            { "czk", "\u010deska krona" },
            { "djf", "d\u017aibutiski frank" },
            { "dkk", "da\u0144ska krona" },
            { "dop", "dominika\u0144ski peso" },
            { "dzd", "algeriski dinar" },
            { "egp", "egyptojski punt" },
            { "ern", "eritrejska nakfa" },
            { "etb", "etiopiski birr" },
            { "eur", "euro" },
            { "fjd", "fid\u017aiski dolar" },
            { "fkp", "falklandski punt" },
            { "gbp", "britiski punt" },
            { "gel", "georgiski lari" },
            { "ghs", "ghanaski cedi" },
            { "gip", "gibraltiski punt" },
            { "gmd", "gambiski dalasi" },
            { "gnf", "guineski frank" },
            { "gtq", "guatemalski quetzal" },
            { "gwp", "Guinea-Bissau peso" },
            { "gyd", "guya\u0144ski dolar" },
            { "hkd", "hongkongski dolar" },
            { "hnl", "honduraska lempira" },
            { "hrk", "chorwatska kuna" },
            { "htg", "haitiska gourda" },
            { "huf", "mad\u017aarski forint" },
            { "idr", "indoneska rupija" },
            { "ils", "israelski nowy \u0161ekel" },
            { "inr", "indiska rupija" },
            { "iqd", "irakski dinar" },
            { "irr", "ira\u0144ski rial" },
            { "isk", "islandska krona" },
            { "jmd", "jamaiski dolar" },
            { "jod", "jordaniski dinar" },
            { "jpy", "japa\u0144ski yen" },
            { "kes", "keniaski \u0161iling" },
            { "kgs", "kirgiski som" },
            { "khr", "kambod\u017easki riel" },
            { "kmf", "komorski frank" },
            { "kpw", "p\u00f3dpo\u0142nocnokorejski won" },
            { "krw", "p\u00f3dpo\u0142dnjowokorejski won" },
            { "kwd", "kuwaitski dinar" },
            { "kyd", "kajmaniski dolar" },
            { "kzt", "kazachski tenge" },
            { "lak", "laoski kip" },
            { "lbp", "libano\u0144ski punt" },
            { "lkr", "sri-lankaska rupija" },
            { "lrd", "liberiski dolar" },
            { "ltl", "litawski litas" },
            { "lvl", "letiski lat" },
            { "lyd", "libyski dinar" },
            { "mad", "marokkoski dirham" },
            { "mdl", "moldawiski leu" },
            { "mga", "madagaskarski ariary" },
            { "mkd", "makedo\u0144ski denar" },
            { "mmk", "myanmarski kyat" },
            { "mnt", "mongolski tugrik" },
            { "mop", "macaoska pataca" },
            { "mro", "maureta\u0144ski ouguiya (1973\u20132017)" },
            { "mru", "maureta\u0144ski ouguiya" },
            { "mur", "mauriciska rupija" },
            { "mvr", "malediwiska rupija" },
            { "mwk", "malawiski kwacha" },
            { "mxn", "mexiski peso" },
            { "myr", "malajziski ringgit" },
            { "mze", "Mozabicke escudo" },
            { "mzm", "mosambikski metical (1980\u20132006)" },
            { "mzn", "mosambikski metical" },
            { "nad", "namibiski dolar" },
            { "ngn", "nigeriska naira" },
            { "nio", "nikaraguaska cordoba" },
            { "nok", "norwegska krona" },
            { "npr", "nepalska rupija" },
            { "nzd", "nowoseelandski dolar" },
            { "omr", "oma\u0144ski rial" },
            { "pab", "panamaski balboa" },
            { "pen", "peruski sol" },
            { "pgk", "papua-neuguinejska kina" },
            { "php", "filipinski peso" },
            { "pkr", "pakista\u0144ska rupija" },
            { "pln", "p\u00f3lski z\u0142oty" },
            { "pyg", "paraguayski guarani" },
            { "qar", "katarski rial" },
            { "ron", "rumu\u0144ski leu" },
            { "rsd", "serbiski dinar" },
            { "rub", "ruski rubl" },
            { "rwf", "ruandiski frank" },
            { "sar", "saudi-arabiski rial" },
            { "sbd", "salomo\u0144ski dolar" },
            { "scr", "seychelska rupija" },
            { "sdg", "suda\u0144ski punt" },
            { "sek", "\u0161wedska krona" },
            { "sgd", "singapurski dolar" },
            { "shp", "St. Helena punt" },
            { "sll", "sierra-leoneski leone" },
            { "sos", "somaliski \u0161iling" },
            { "srd", "surinamski dolar" },
            { "ssp", "p\u00f3dpo\u0142dnjowosuda\u0144ski punt" },
            { "std", "s\u00e3o-tomeska dobra (1977\u20132017)" },
            { "stn", "s\u00e3o-tomeska dobra" },
            { "svc", "el-salvadorski col\u00f3n" },
            { "syp", "syriski punt" },
            { "szl", "swasiski lilangeni" },
            { "thb", "thaiski baht" },
            { "tjs", "tad\u017aikiski somoni" },
            { "tmt", "turkmeniski manat" },
            { "tnd", "tuneziski dinar" },
            { "top", "tongaski pa\u02bbanga" },
            { "try", "turkojska lira" },
            { "ttd", "trinidad-tobagoski dolar" },
            { "twd", "nowy taiwa\u0144ski dolar" },
            { "tzs", "tansaniski \u0161iling" },
            { "uah", "ukrainska griwna" },
            { "ugx", "ugandaski \u0161iling" },
            { "usd", "ameriski dolar" },
            { "uyu", "uruguayski peso" },
            { "uzs", "usbekiski sum" },
            { "vef", "venezuelski bol\u00edvar (2008\u20132018)" },
            { "ves", "venezuelski bol\u00edvar" },
            { "vnd", "vietnamski dong" },
            { "vuv", "vanuatski vatu" },
            { "wst", "samoaska tala" },
            { "xaf", "CFA-frank (BEAC)" },
            { "xcd", "p\u00f3dzajt\u0161nokaribiski dolar" },
            { "xof", "CFA-frank (BCEAO)" },
            { "xpf", "CFP-frank" },
            { "xxx", "njeznate pjenjeze" },
            { "yer", "jeme\u0144ski rial" },
            { "zar", "p\u00f3dpo\u0142dnjowoafriski rand" },
            { "zmw", "sambiska kwacha" },
        };
        return data;
    }
}
